==> orchestra-api-4.4.1-sources.jar: org/ow2/orchestra/facade/runtime/impl/CompensationHandlerActivityInstanceImpl.java <==
/**
 * Copyright (C) 2009 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.facade.runtime.impl;

import org.ow2.orchestra.facade.runtime.ActivityType;
import org.ow2.orchestra.facade.runtime.CompensationHandlerActivityInstance;

/**
 * @author S. Ali Tokmen
 */
public class CompensationHandlerActivityInstanceImpl extends ActivityWithSingleChildInstanceImpl implements
  CompensationHandlerActivityInstance {

  private static final long serialVersionUID = 910976890428107036L;

  public CompensationHandlerActivityInstanceImpl(
    final CompensationHandlerActivityInstance CompensationHandlerActivityInstanceImpl) {
    super(CompensationHandlerActivityInstanceImpl);
  }

  public ActivityType getType() {
    return ActivityType.COMPENSATION_HANDLER;
  }

}

==> orchestra-api-4.7.1-sources.jar: org/ow2/orchestra/facade/runtime/impl/CompensationHandlerActivityInstanceImpl.java <==
/**
 * Copyright (C) 2009 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.facade.runtime.impl;

import org.ow2.orchestra.facade.runtime.ActivityType;
import org.ow2.orchestra.facade.runtime.CompensationHandlerActivityInstance;

/**
 * @author S. Ali Tokmen
 */
public class CompensationHandlerActivityInstanceImpl extends ActivityWithSingleChildInstanceImpl implements
  CompensationHandlerActivityInstance {

  private static final long serialVersionUID = 910976890428107036L;

  public CompensationHandlerActivityInstanceImpl(
    final CompensationHandlerActivityInstance compensationHandlerActivityInstanceImpl) {
    super(compensationHandlerActivityInstanceImpl);
  }

  public ActivityType getType() {
    return ActivityType.COMPENSATION_HANDLER;
  }

}
